@@ -1,10 +1,6 @@
 package IO::Pty::Easy;
-BEGIN {
-  $IO::Pty::Easy::AUTHORITY = 'cpan:DOY';
-}
-{
-  $IO::Pty::Easy::VERSION = '0.09';
-}
+our $AUTHORITY = 'cpan:DOY';
+$IO::Pty::Easy::VERSION = '0.10';
 use warnings;
 use strict;
 # ABSTRACT: Easy interface to IO::Pty
@@ -246,15 +242,18 @@ sub DESTROY {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 IO::Pty::Easy - Easy interface to IO::Pty
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -315,9 +314,9 @@ after C<spawn()>. Defaults to true.
 
 Fork a new subprocess, with stdin/stdout/stderr tied to the pty.
 
-The argument list is passed directly to C<exec()>.
+The argument list is passed directly to C<system()>.
 
-Returns true on success, false on failure.
+Dies on failure.
 
 =head2 read($timeout, $length)
 
@@ -434,10 +433,9 @@ Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Jesse Luehrs.
+This software is copyright (c) 2016 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
